bayespy.inference.vmp.nodes.stochastic.Stochastic
=================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. autoclass:: Stochastic

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Stochastic.__init__
      ~Stochastic.add_plate_axis
      ~Stochastic.broadcasting_multiplier
      ~Stochastic.delete
      ~Stochastic.get_mask
      ~Stochastic.get_moments
      ~Stochastic.get_shape
      ~Stochastic.has_plotter
      ~Stochastic.load
      ~Stochastic.lowerbound
      ~Stochastic.move_plates
      ~Stochastic.observe
      ~Stochastic.plot
      ~Stochastic.random
      ~Stochastic.save
      ~Stochastic.set_plotter
      ~Stochastic.show
      ~Stochastic.unobserve
      ~Stochastic.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Stochastic.plates
      ~Stochastic.plates_multiplier
   
   